Confectioner API
================

Core API
--------
.. automodule:: confectioner.core
   :members:
   :special-members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: confectioner.baker.Baker
    :special-members:

File Utilities
--------------
.. automodule:: confectioner.files
   :members:
   :special-members:
   :inherited-members:
   :show-inheritance:

Templating Utilities
--------------------
.. automodule:: confectioner.templating
   :members:
